pub struct ResolvedAddr {
pub server: ServerAddr,
pub socket: SocketAddr,
}Expand description
An address that may be used to connect to a Minecraft server.
Fields
server: ServerAddrThe initial address that we passed when trying to connect.
This is necessary because clients send this to the server when they connect.
socket: SocketAddrThe IP and port that we will actually connect to.
Implementations
Sourceimpl ResolvedAddr
impl ResolvedAddr
pub async fn new(server: impl Into<ServerAddr>) -> Result<Self, ResolveError>